package net.moioli.complessi;

import java.awt.Color;
import java.awt.Graphics;

import net.moioli.grafici.Disegnabile;
import net.moioli.grafici.Scala;
import net.moioli.grafici.VettoreDisegnabile;

/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */

/**
 * Una forma che permette anche il tracciamento su un oggetto Grafico.
 */
public class FormaGrafica extends FormaAlgebrica implements Disegnabile {

	/** Costruttore standard */
	public FormaGrafica(NumeroComplesso nc) {
		super(nc);
	}

	/**
	 * Implementa Disegnabile. L'utente non dovrebbe mai richiamare questo
	 * metodo, visto che e' richiamato automaticamente dall'oggetto Grafico.
	 * All'interno di questo metodo dovrebbe esserci tutto il codice necessario
	 * al tracciamento sul video di quest'oggetto. Tutte le operaizoni di scala
	 * dovrebbero essere fatte esclusivamente tramite l'oggetto ScalaGrafico
	 * passato.
	 * 
	 * @param g la superficie dove questo oggetto verra' disegnato
	 * @param s l'oggetto Scala da utilizzare per il tracciamento dell'oggetto
	 * @param c il colore con cui disegnare l'oggetto
	 */
	public void disegnami(Graphics g, Scala s, Color c) {
		new VettoreDisegnabile(this.getA(), this.getB()).disegnami(g, s, c);
	}

	/**
	 * Ritorna una rappresentazione in stringa del numero complesso.
	 * 
	 * @return una String
	 */
	public String toString() {
		return "(" + getA() + "," + getB() + ")";
	}

	/**
	 * Ritorna la minima ordinata dell'oggetto da rappresentare se ne fosse
	 * disegnata la porzione compresa fra un'ascissa minima e una massima.<br>
	 * 
	 * Se l'oggetto in questione non ha una ordinata massima o non ha senso
	 * definirne una, questa funzione deve ritornare il valore Double.NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il minimo valore delle ordinate o NaN
	 */
	public double minY(double minX, double maxX) {
		return -10;
	}

	/**
	 * Ritorna la massima ordinata dell'oggetto da rappresentare se ne fosse
	 * disegnata la porzione compresa fra un'ascissa minima e una massima.<br>
	 * 
	 * Se l'oggetto in questione non ha una ordinata minima o non ha senso
	 * definirne una, questa funzione deve ritornare il valore Double.NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il massimo valore delle ordinate o NaN
	 */
	public double maxY(double minX, double maxX) {
		return 10;
	}
}
