package net.moioli.complessi;

/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */

/**
 * Una raccolta di metodi statici per le operazioni sui numeri complessi.
 */
public class MatematicaComplessa {
	/**
	 * Indicazione sul pattern: Template method Ritorna un nuovo numero
	 * complesso che e' la somma di quelli passati.
	 * 
	 * @param z1 il primo addendo
	 * @param z2 il secondo addendo
	 * @return la somma
	 */
	public static NumeroComplesso somma(NumeroComplesso z1, NumeroComplesso z2) {
		// Uso la regola:
		// (a+ib) + (c+id) = (a+c) + i(b+d)
		return new FormaAlgebrica(z1.getA() + z2.getA(), z1.getB() + z2.getB());
	}

	/**
	 * Indicazione sul pattern: Template method Ritorna un nuovo numero
	 * complesso che e' la differenza di quelli passati.
	 * 
	 * @param z1 il minuendo
	 * @param z2 il sottraendo
	 * @return la differenza
	 */
	public static NumeroComplesso sottrai(NumeroComplesso z1, NumeroComplesso z2) {
		// Uso la regola:
		// (a+ib) - (c+id) = (a-c) + i(b-d)
		return new FormaAlgebrica(z1.getA() - z2.getA(), z1.getB() - z2.getB());
	}

	/**
	 * Indicazione sul pattern: Template method Ritorna un nuovo numero
	 * complesso che e' il prodotto di quelli passati.
	 * 
	 * @param z1 il primo fattore
	 * @param z2 il secondo fattore
	 * @return il prodotto
	 */
	public static NumeroComplesso moltiplica(NumeroComplesso z1,
			NumeroComplesso z2) {
		// Uso la regola:
		// (m1*e^f1)*(m2*e^f2) = m1m2*e^(f1+f2)
		return new FormaEsponenziale(z1.getModulo() * z2.getModulo(), z1
				.getFase() + z2.getFase());
	}

	/**
	 * Indicazione sul pattern: Template method Ritorna un nuovo numero
	 * complesso che e' il quoziente di quelli passati.
	 * 
	 * @param z1 il dividendo
	 * @param z2 il divisore
	 * @return il quoziente
	 */
	public static NumeroComplesso dividi(NumeroComplesso z1, NumeroComplesso z2) {
		// Uso la regola:
		// (m1*e^f1)/(m2*e^f2) = m1/m2*e^(f1-f2)
		return new FormaEsponenziale(z1.getModulo() / z2.getModulo(), z1
				.getFase() - z2.getFase());
	}
}
