package net.moioli.complessi;

/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */

/**
 * Interfaccia comune a tutte le rappresentazioni dei numeri complessi.
 */
public interface NumeroComplesso {
	/**
	 * Ritorna la parte reale del numero complesso, ovvero il coefficiente "a"
	 * nella forma "a+ib".
	 * 
	 * @return la parte reale
	 */
	public /*@ pure @*/ double getA();

	/**
	 * Ritorna la parte immaginaria del numero complesso, ovvero il coefficiente
	 * "b" nella forma "a+ib".
	 * 
	 * @return la parte immaginaria
	 */
	public /*@ pure @*/ double getB();

	/**
	 * Ritorna il modulo del numero complesso, ovvero il valore dell'espressione
	 * "sqrt(a^2+b^2)" nella forma "a+ib".
	 * 
	 * @return il modulo
	 */
	public /*@ pure @*/ double getModulo();

	/**
	 * Ritorna la fase del numero complesso, ovvero il valore dell'espressione
	 * "arctg(b/a)" nella forma "a+ib".
	 * 
	 * @return la fase
	 */
	public /*@ pure @*/ double getFase();

	/**
	 * Ritorna una rappresentazione in stringa del numero complesso (a seconda
	 * dell'implementazione).
	 * 
	 * @return una String
	 */
	public /*@ pure @*/ String toString();
}
