package net.moioli.grafici;
/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */
import java.awt.Color;
import java.awt.Graphics;


/**
 * Descrive un oggetto che puo' essere inserito (e disegnato) su un Grafico.
 */
public interface Disegnabile {
	/**
	 * L'utente non dovrebbe mai richiamare questo metodo, visto che e'
	 * richiamato automaticamente dall'oggetto Grafico. All'interno di questo
	 * metodo dovrebbe esserci tutto il codice necessario al tracciamento sul
	 * video di quest'oggetto. Tutte le operaizoni di scala dovrebbero essere
	 * fatte esclusivamente tramite l'oggetto ScalaGrafico passato.
	 * 
	 * @param g la superficie dove questo oggetto verra' disegnato
	 * @param s l'oggetto Scala da utilizzare per il tracciamento dell'oggetto
	 * @param c il colore con cui disegnare l'oggetto
	 */
	public void disegnami(Graphics g, Scala s, Color c);

	/**
	 * Ritorna la minima ordinata dell'oggetto da rappresentare se ne fosse
	 * disegnata la porzione compresa fra un'ascissa minima e una massima.<br>
	 * 
	 * Se l'oggetto in questione non ha una ordinata massima o non ha senso
	 * definirne una, questa funzione deve ritornare il valore Double.NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il minimo valore delle ordinate o NaN
	 */
	public double minY(double minX, double maxX);

	/**
	 * Ritorna la massima ordinata dell'oggetto da rappresentare se ne fosse
	 * disegnata la porzione compresa fra un'ascissa minima e una massima.<br>
	 * 
	 * Se l'oggetto in questione non ha una ordinata minima o non ha senso
	 * definirne una, questa funzione deve ritornare il valore Double.NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il massimo valore delle ordinate o NaN
	 */
	public double maxY(double minX, double maxX);
}
