package net.moioli.grafici;
/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.util.Collection;
import java.util.Iterator;

import javax.swing.JPanel;

/**
 * Decorator per Grafico, basato su un JPanel.
 * 
 * Permette di disegnare un Grafico in ambiente Swing. Un qualsiasi cambiamento
 * alla collezione sottostante (CompatibleCollection) verra' automaticamente
 * riflesso nel grafico visualizzato.
 */
public class JGrafico extends JPanel implements IGrafico, CompatibleCollection {

	/**
	 * ID per la serializzazione.
	 */
	private static final long serialVersionUID = -3699636600707670581L;
	
	// Il grafico da disegnare
	private Grafico g = new Grafico();

	/**
	 * Costruisce un grafico vuoto.
	 */
	public JGrafico() {
		setGrafico(new Grafico());
		setPreferredSize(new Dimension(300, 300));
	}

	/**
	 * Costruisce un grafico con piu' oggetti.
	 * 
	 * @param g Grafico da rappresentare
	 */
	public JGrafico(Grafico g) {
		setGrafico(g);
		setPreferredSize(new Dimension(300, 300));
	}

	public void paint(Graphics g) {
		super.paint(g);
		Rectangle r = getBounds();
		if ((r.getHeight() > 30) && (r.getWidth() > 30)) {
			disegnami(g, r);
		}
	}

	public Object clone() {
		return new JGrafico(g);
	}

	public IGrafico getGrafico() {
		return g;
	}

	public void setGrafico(Grafico g) {
		this.g = g;
		repaint();
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean add(Object arg0) {
		boolean result = g.add(arg0);
		repaint();
		return result;
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean addAll(Collection arg0) {
		boolean result = g.addAll(arg0);
		repaint();
		return result;
	}

	/**
	 * 
	 */
	public void clear() {
		g.clear();
		repaint();
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean contains(Object arg0) {
		return g.contains(arg0);
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean containsAll(Collection arg0) {
		return g.containsAll(arg0);
	}

	/**
	 * @param g
	 * @param clip
	 */
	public void disegnami(Graphics g, Rectangle clip) {
		this.g.disegnami(g, clip);
	}

	/**
	 * @return
	 */
	public Color getColor() {
		return g.getColor();
	}

	/**
	 * @return
	 */
	public double getMaxX() {
		return g.getMaxX();
	}

	/**
	 * @return
	 */
	public double getMinX() {
		return g.getMinX();
	}

	/**
	 * @return
	 */
	public double getMaxY() {
		return g.getMaxY();
	}

	/**
	 * @return
	 */
	public double getMinY() {
		return g.getMinY();
	}

	/**
	 * @return
	 */
	public int getPrecisionePixel() {
		return g.getPrecisionePixel();
	}

	/**
	 * @return
	 */
	public boolean isEmpty() {
		return g.isEmpty();
	}

	/**
	 * @return
	 */
	public Iterator iterator() {
		return g.iterator();
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean remove(Object arg0) {
		boolean result = g.remove(arg0);
		repaint();
		return result;
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean removeAll(Collection arg0) {
		boolean result = g.removeAll(arg0);
		repaint();
		return result;
	}

	/**
	 * @param arg0
	 * @return
	 */
	public boolean retainAll(Collection arg0) {
		boolean result = g.retainAll(arg0);
		repaint();
		return result;
	}

	/**
	 * @param color
	 */
	public void setColor(Color color) {
		g.setColor(color);
		repaint();
	}

	/**
	 * @param maxY
	 */
	public void setMaxX(double maxX) {
		g.setMaxX(maxX);
		repaint();
	}

	/**
	 * @param minY
	 */
	public void setMinX(double minX) {
		g.setMinX(minX);
		repaint();
	}

	/**
	 * @param maxY
	 */
	public void setMaxY(double maxY) {
		g.setMaxY(maxY);
		repaint();
	}

	/**
	 * @param minY
	 */
	public void setMinY(double minY) {
		g.setMinY(minY);
		repaint();
	}

	/**
	 * @param precisionePixel
	 */
	public void setPrecisionePixel(int precisionePixel) {
		g.setPrecisionePixel(precisionePixel);
		repaint();
	}

	/*
	 * (non Javadoc)
	 * 
	 * @see java.awt.Component#size()
	 */
	public int getCollectionSize() {
		return g.getCollectionSize();
	}

	/**
	 * @return
	 */
	public Object[] toArray() {
		return g.toArray();
	}

	/**
	 * @param arg0
	 * @return
	 */
	public Object[] toArray(Object[] arg0) {
		return g.toArray(arg0);
	}

	/*
	 * (non Javadoc)
	 * 
	 * @see java.awt.Component#toString()
	 */
	public String toString() {
		return g.toString();
	}
}
