package net.moioli.grafici;

/**
 * Rappresentazioni alternative dei numeri complessi
 * 
 * Versione originale: 2/12/2003
 * Versione JML: 28/11/2007
 * Autore: Silvio Moioli
 */

import java.awt.Color;
import java.awt.Graphics;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * Rappresenta una leggenda composta da piu' elementi.
 */
class Legenda implements Disegnabile {
	/** Contiene gli elementi di questa legenda */
	private ArrayList elementi = new ArrayList();

	/**
	 * Costruttore di default
	 */
	public Legenda() {
	}

	/**
	 * Costruttore comprensivo del primo elemento
	 * 
	 * @param e Il primo elemento della legenda
	 */
	public Legenda(ElementoLegenda e) {
		this();
		elementi.add(e);
	}

	/**
	 * Costruttore completo
	 * 
	 * @param e L'array di elementi costitutivi della legenda
	 */
	public Legenda(ElementoLegenda e[]) {
		this();
		for (int i = 0; i < e.length; i++) {
			elementi.add(e[i]);
		}
	}

	/**
	 * Implementa l'interfaccia Disegnabile, disegnando questo oggetto.
	 * 
	 * @param g l'oggetto di grafica sul quale disegnare
	 * @param s la scala relativa al grafico e all'oggetto Graphics
	 * @param c il colore con cui disegnare questo oggetto
	 */
	public void disegnami(Graphics g, Scala s, Color c) {
		int x = s.getScreenMaxX();
		int y = 0;
		g.drawString("Legenda:",
				x - g.getFontMetrics().stringWidth("Legenda:"), y
						+ g.getFontMetrics().getHeight());
		y += g.getFontMetrics().getHeight();
		Iterator i = elementi.iterator();
		while (i.hasNext()) {
			ElementoLegenda e = (ElementoLegenda) i.next();
			e.setXY(x, y);
			e.disegnami(g, s, c);
			y += e.getHeight(g);
		}
	}

	/**
	 * Dal momento che la legenda viene comunque disegnata, questa
	 * implementazione ritorna sempre NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il massimo valore delle ordinate o NaN
	 */
	public double maxY(double minX, double maxX) {
		return Double.NaN;
	}

	/**
	 * Dal momento che la legenda viene comunque disegnata, questa
	 * implementazione ritorna sempre NaN.
	 * 
	 * @param minX il minimo valore reale delle x dell'intervallo
	 * @param maxX il massimo valore reale delle x dell'intervallo
	 * @return il massimo valore delle ordinate o NaN
	 */
	public double minY(double minX, double maxX) {
		return Double.NaN;
	}
}
